@@ -31,7 +31,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
     '''Test the power plugin'''
 
     def setUp(self):
-        os.environ.set('GSD_MOCK', '1')
+        os.environ['GSD_MOCK']='1'
         self.check_logind_gnome_session()
         self.start_logind()
         self.daemon_death_expected = False
@@ -59,7 +59,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
 
         # start mock upowerd
         (self.upowerd, self.obj_upower) = self.spawn_server_template(
-            'upower', {'OnBattery': True, 'LidIsClosed': False}, stdout=subprocess.PIPE)
+            'upower', {'DaemonVersion': '0.99', 'OnBattery': True, 'LidIsClosed': False}, stdout=subprocess.PIPE)
         gsdtestcase.set_nonblock(self.upowerd.stdout)
 
         # start mock gnome-shell screensaver
@@ -84,11 +84,6 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
 
         self.settings_gsd_power = Gio.Settings('org.gnome.settings-daemon.plugins.power')
 
-        # start power plugin
-        self.settings_gsd_power['active'] = False
-        # As hibernate is not available, suspend by default on critical
-        # FIXME
-        self.settings_gsd_power['critical-battery-action'] = 'suspend'
         Gio.Settings.sync()
         self.plugin_log_write = open(os.path.join(self.workdir, 'plugin_power.log'), 'wb')
         # avoid painfully long delays of actions for tests
@@ -99,7 +94,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         env['CANBERRA_DRIVER'] = 'null'
 
         self.daemon = subprocess.Popen(
-            [os.path.join(builddir, 'gsd-test-power')],
+            [os.path.join(builddir, 'gsd-power')],
             # comment out this line if you want to see the logs in real time
             stdout=self.plugin_log_write,
             stderr=subprocess.STDOUT,
@@ -180,9 +175,19 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
 
         path = GLib.find_program_in_path ('gnome-session')
         assert(path)
+        (success, data) = GLib.file_get_contents (path)
+        lines = data.split('\n')
+        new_path = None
+        for line in lines:
+            items = line.split()
+            if items and items[0] == 'exec':
+                new_path = items[1]
+        if not new_path:
+            self.fail("could not get gnome-session's real path from %s" % path)
+        path = new_path
         ldd = subprocess.Popen(['ldd', path], stdout=subprocess.PIPE)
         out = ldd.communicate()[0]
-        if not 'libsystemd-login.so.0' in out:
+        if not 'libsystemd.so.0' in out:
             self.fail('gnome-session is not built with logind support')
 
     def get_status(self):
@@ -497,7 +502,7 @@ class PowerPluginTest(gsdtestcase.GSDTestCase):
         # delay + 1 s error margin
         self.check_for_suspend(7)
 
-    def test_suspend_no_hibernate(self):
+    def _test_suspend_no_hibernate(self):
         '''suspend-no-hibernate'''
 
         self.settings_session['idle-delay'] = 2
